@@ -1,9 +1,9 @@
-from collections import Counter
 from dataclasses import dataclass
+from itertools import combinations
 
 from mypy.nodes import ComparisonExpr, Expression, OpExpr
 
-from refurb.checks.common import extract_binary_oper
+from refurb.checks.common import extract_binary_oper, is_equivalent
 from refurb.error import Error
 
 
@@ -31,25 +31,22 @@ class ErrorInfo(Error):
     """
 
     code = 124
-    msg: str = "Use `x == y == z` instead of `x == y and x == z`"
+    msg: str = "Replace `x == y and x == z` with `x == y == z`"
+    categories = ["logical", "readability"]
 
 
-def has_common_expr(exprs: tuple[Expression, ...]) -> bool:
-    count = Counter(str(x) for x in exprs).most_common(1)[0][1]
+def has_common_expr(*exprs: Expression) -> bool:
+    for lhs, rhs in combinations(exprs, 2):
+        if is_equivalent(lhs, rhs):
+            return True
 
-    return count > 1
+    return False
 
 
 def check(node: OpExpr, errors: list[Error]) -> None:
-    exprs = extract_binary_oper("and", node)
-
-    # TODO: remove when next mypy version is released
-    if not exprs:
-        return
-
-    match exprs:
+    match extract_binary_oper("and", node):
         case (
             ComparisonExpr(operators=["=="], operands=[a, b]),
             ComparisonExpr(operators=["=="], operands=[c, d]),
-        ) if has_common_expr((a, b, c, d)):
+        ) if has_common_expr(a, b, c, d):
             errors.append(ErrorInfo(a.line, a.column))
