@@ -2,7 +2,7 @@ from dataclasses import dataclass
 
 from mypy.nodes import ComparisonExpr, OpExpr
 
-from refurb.checks.common import extract_binary_oper
+from refurb.checks.common import extract_binary_oper, is_equivalent
 from refurb.error import Error
 
 
@@ -32,19 +32,14 @@ class ErrorInfo(Error):
     """
 
     code = 108
-    msg: str = "Use `x in (y, z)` instead of `x == y or x == z`"
+    msg: str = "Replace `x == y or x == z` with `x in (y, z)`"
+    categories = ["logical", "readability"]
 
 
 def check(node: OpExpr, errors: list[Error]) -> None:
-    exprs = extract_binary_oper("or", node)
-
-    # TODO: remove when next mypy version is released
-    if not exprs:
-        return
-
-    match exprs:
+    match extract_binary_oper("or", node):
         case (
             ComparisonExpr(operators=["=="], operands=[lhs, _]),
             ComparisonExpr(operators=["=="], operands=[rhs, _]),
-        ) if str(lhs) == str(rhs):
+        ) if is_equivalent(lhs, rhs):
             errors.append(ErrorInfo(lhs.line, lhs.column))
