@@ -2,6 +2,7 @@ from dataclasses import dataclass
 
 from mypy.nodes import ConditionalExpr
 
+from refurb.checks.common import is_equivalent
 from refurb.error import Error
 
 
@@ -9,7 +10,7 @@ from refurb.error import Error
 class ErrorInfo(Error):
     """
     Sometimes ternary (aka, inline if statements) can be simplified to a single
-    or expression.
+    `or` expression.
 
     Bad:
 
@@ -27,9 +28,10 @@ class ErrorInfo(Error):
     """
 
     code = 110
-    msg: str = "Use `x or y` instead of `x if x else y`"
+    msg: str = "Replace `x if x else y` with `x or y`"
+    categories = ["logical", "readability"]
 
 
 def check(node: ConditionalExpr, errors: list[Error]) -> None:
-    if str(node.if_expr) == str(node.cond):
+    if is_equivalent(node.if_expr, node.cond):
         errors.append(ErrorInfo(node.line, node.column))
